@@ -310,7 +310,10 @@ class KeepOtherWordsNormalizer(NormalizerMixin):
                 if element_lhs == "TY0P":
                     lhs_remove = [k for k, v in lhs_all_abrv.items() if element_lhs in v]
                     if len(lhs_remove) > 0:
-                        normalized_lhs.remove(lhs_remove[0])
+                        try:
+                            normalized_lhs.remove(lhs_remove[0])
+                        except:
+                            pass
                 for elements_rhs in rhs_all_abrv.values():
                     if element_lhs in elements_rhs:
                         lhs_element_lhs_to_remove = [k for k, v in lhs_all_abrv.items() if element_lhs in v]
@@ -321,16 +324,15 @@ class KeepOtherWordsNormalizer(NormalizerMixin):
                         if len(rhs_element_lhs_to_remove) > 0:
                             if rhs_element_lhs_to_remove[0] in normalized_rhs:
                                 normalized_rhs.remove(rhs_element_lhs_to_remove[0])
-        print(rhs_all_abrv.values())
         for elements_rhs in rhs_all_abrv.values():
             for element_rhs in elements_rhs:        
                 if element_rhs == "TY0P":
                     rhs_remove = [k for k, v in rhs_all_abrv.items() if element_rhs in v]
-                    print(rhs_remove)
-                    print(rhs_remove[0])
-                    print(normalized_rhs)
                     if len(rhs_remove) > 0:
-                        normalized_rhs.remove(rhs_remove[0])
+                        try:
+                            normalized_rhs.remove(rhs_remove[0])
+                        except:
+                            pass
         return normalized_lhs, normalized_rhs
 
 
